<?php

namespace Roots\Sage\ACF;

// ACF Theme Options Page
function root_options_page() {
	static $options_page = null;

	if ( is_null( $options_page ) && function_exists('acf_add_options_page') ) {
		$options_page = acf_add_options_page([
			'menu_title' => 'Theme Settings',
			'redirect'   => false
		]);
	}

	return $options_page;
}
add_action( 'acf/init', __NAMESPACE__.'\\root_options_page' );

// Helper function to easily register ACF fields
function register_groups( $groups ) {
	if ( !function_exists('acf_add_local_field_group') ) {
		return;
	}

	foreach ( $groups as $group_name => $group_options ) {
		$_options = array_merge( [], $group_options, [
			'key' => 'group_' . $group_name,
			'private' => true,
		] );
		// Register fields explicitly below
		unset( $_options['fields'] );
		acf_add_local_field_group( $_options );

		foreach ( $group_options['fields'] as $field_name => $field_options ) {
			$field_key = sprintf( 'field_%s_%s', $group_name, $field_name );
			$_options = array_merge( [
				'name' => $field_name,
				'_name' => $field_name,
				'key' => $field_key,
				'parent' => 'group_' . $group_name,
			], $field_options );

			if ( array_key_exists( 'sub_fields', $_options ) ) {
				$_options['sub_fields'] = _create_sub_fields( $_options, $_options['sub_fields'] );
			}

			acf_add_local_field( $_options );
		}
	}
}

function _create_sub_fields( $parent, $raw_sub_fields ) {
	$sub_fields = [];
	foreach ( $raw_sub_fields as $field_name => $raw_options ) {
		$field_key = sprintf( '%s_%s', $parent['key'], $field_name );
		$field_options = array_merge( [
			'name' => $field_name,
			'_name' => $field_name,
			'key' => $field_key,
			'required' => 0,
		], $raw_options );

		if ( array_key_exists( 'sub_fields', $field_options ) ) {
			$field_options['sub_fields'] = _create_sub_fields( $field_options, $field_options['sub_fields'] );
		}

		$sub_fields[] = $field_options;
	}
	return $sub_fields;
}

//Set Maps API Key using https://support.advancedcustomfields.com/forums/topic/google-maps-field-needs-setting-to-add-api-key/page/3/
///Not https://www.advancedcustomfields.com/blog/google-maps-api-settings/

add_filter('acf/settings/google_api_key', function ($value) {
	return 'AIzaSyDGRHK9HASoX6CDHzWQxWX-hIVg_Ez8Wx0';
});
