<?php

namespace Roots\Sage\ContactMap;

use Roots\Sage\ACF;

// Custom Fields Definition
function register_custom_fields() {

	ACF\register_groups([
		'contact_locations' => [
			'title' => 'Contact Locations',
			'menu_order' => 0,
			'position' => 'normal',
			'style' => 'seamless',
			'label_placement' => 'top',
			'instruction_placement' => 'label',
			'hide_on_screen' => '',
			'active' => 1,
			'description' => '',
			'location' => [
				[
					[
						'param' => 'options_page',
						'operator' => '==',
						'value' => 'acf-options-contact-locations',
					],
				],
			],
			'fields' => [
				'contact_locations' => [
					'label' => 'Locations',
					'type' => 'repeater',
					'layout' => 'block',
					'collapsed' => 'field_contact_locations_contact_locations_title',
					'button_label' => 'Add Location',
					'sub_fields' => [
						'title' => [
							'label' => 'Title',
							'type' => 'text',
							'wrapper' => [ 'class' => '', ], // Required for parent collapse function
						],
						'phone' => [
							'label' => 'Phone',
							'type' => 'text',
						],
						'website' => [
							'label' => 'Website',
							'type' => 'url',
						],
						'override_displayed_address' => [
							'label' => 'Override displayed address?',
							'type' => 'true_false',
							'instructions' => 'Show a nicer-looking address to the user.',
							'ui' => 1,
							'ui_on_text' => 'Yes',
							'ui_off_text' => 'No',
						],
						'displayed_address' => [
							'label' => 'Displayed address',
							'type' => 'textarea',
							'new_lines' => 'br',
							'rows' => 3,
							'conditional_logic' => [
								[
									[
										'field' => 'field_contact_locations_contact_locations_override_displayed_address',
										'operator' => '==',
										'value' => '1',
									],
								],
							],
						],
						'address' => [
							'label' => 'Address',
							'type' => 'google_map',
							'height' => 250,
						],
					],
				],
			],
		],
	]);

}
add_action( 'acf/init', __NAMESPACE__.'\\register_custom_fields' );

// Custom Fields Page
function register_options_page() {
	if ( function_exists('acf_add_options_sub_page') ) {

		$options_root = \Roots\Sage\ACF\root_options_page();

		acf_add_options_sub_page(array(
			'page_title'  => 'Contact Locations',
			'menu_title'  => 'Contact Locations',
			'parent_slug' => $options_root['menu_slug'],
		));

	}
}
add_action( 'init', __NAMESPACE__.'\\register_options_page' );

// Register Google Maps API JS
function register_google_js() {
	if ( function_exists('acf_get_setting') ) {

		$api_key = acf_get_setting( 'google_api_key' );
		wp_register_script( 'google-maps-api', 'https://maps.googleapis.com/maps/api/js?' . http_build_query(['key' => $api_key, 'callback' => 'googleMapsLoaded']), null, null, true );

	}
}
add_action( 'wp_enqueue_scripts', __NAMESPACE__.'\\register_google_js' );
