<?php

namespace Roots\Sage\Form;

class Example extends \Roots\Sage\Form {

	public $url        = '/things/';
	public $url_ep     = 'edit'; // Endpoint name ( /things/edit/1234/ )
	public $url_ep_new = 'new'; // Endpoint value for new entries ( /things/edit/new/ )
	public $post_type  = 'page';
	public $title      = 'Example Submission';
	public $content    = '[advanced_form form="form_submit_example"]';
	public $template   = null;

	// Must begin with 'form_'
	public $form_key   = 'form_submit_example';
	public $restricted = 1;

	/**
	 * Post will automatically expire
	 * Requires method get_expiry_key() to be defined.
	 * Method should return the meta key of the expiry timestamp
	 */
	//use Feature\Expiry;

	/**
	 * Form has an additional button for saving a post as a draft
	 * Automatically disables validation
	 */
	//use Feature\Draft;

	public function __construct() {
		self::setup();

		$this->define_acf_groups();

		parent::__construct();
	}

	private function define_acf_groups() {
		$this->acf_groups = [
			'example_form' => [
				'title' => 'Example Form',
				'menu_order' => 1,
				'location' => [
					[
						[
							'param' => 'af_form',
							'operator' => '==',
							'value' => $this->form_key,
						],
					]
				],
				'fields' => [
					'title' => [
						'label' => 'Title',
						'type' => 'text',
						'required' => 1,
						'instructions' => 'Some info to help the user understand what to provide.'
					],
					'content' => [
						'label' => 'Content',
						'type' => 'wysiwyg',
						'tabs' => 'visual',
						'toolbar' => 'basic',
						'media_upload' => 0,
						'required' => 1,
					],
					'image' => [
						'label' => 'Image',
						'type' => 'image',
						'mime_types' => 'jpg,jpeg',
						'max_size' => 2,
					],
					'file' => [
						'label' => 'File',
						'type' => 'file',
					],
					'gallery' => [
						'label' => 'Gallery',
						'type' => 'gallery',
					],
					'text_prepend' => [
						'label' => 'Text - Prepend',
						'type' => 'text',
						'prepend' => '$',
					],
					'text_append' => [
						'label' => 'Text - Append',
						'type' => 'text',
						'append' => 'days',
					],
					'text_prepend_append' => [
						'label' => 'Text - Prepend & Append',
						'type' => 'text',
						'prepend' => '$',
						'append' => '.00',
					],
					'select' => [
						'label' => 'Select',
						'type' => 'select',
						'choices' => [
							'Option 0',
							'Option 1',
							'Option 2',
							'Option 3',
							'Option 4',
						],
						'allow_null' => 1,
					],
					'select_ui' => [
						'label' => 'Select with UI',
						'type' => 'select',
						'choices' => [
							'Option 0',
							'Option 1',
							'Option 2',
							'Option 3',
							'Option 4',
						],
						'allow_null' => 1,
						'ui' => 1,
					],
					'select_multi' => [
						'label' => 'Select Multiple',
						'type' => 'select',
						'choices' => [
							'Option 0',
							'Option 1',
							'Option 2',
							'Option 3',
							'Option 4',
						],
						'allow_null' => 1,
						'multiple' => 1,
					],
					'select_multi_ui' => [
						'label' => 'Select Multiple with UI',
						'type' => 'select',
						'choices' => [
							'Option 0',
							'Option 1',
							'Option 2',
							'Option 3',
							'Option 4',
						],
						'allow_null' => 1,
						'multiple' => 1,
						'ui' => 1,
					],
					'checkbox' => [
						'label' => 'Checkbox',
						'type' => 'checkbox',
						'choices' => [
							'Option 0',
							'Option 1',
							'Option 2',
							'Option 3',
							'Option 4',
						],
					],
					'checkbox_custom' => [
						'label' => 'Checkbox with Custom',
						'type' => 'checkbox',
						'choices' => [
							'Option 0',
							'Option 1',
							'Option 2',
							'Option 3',
							'Option 4',
						],
						'allow_custom' => 1,
					],
					'radio' => [
						'label' => 'Radio',
						'type' => 'radio',
						'choices' => [
							'Option 0',
							'Option 1',
							'Option 2',
							'Option 3',
							'Option 4',
						],
						'allow_null' => 1,
					],
					'radio_other' => [
						'label' => 'Radio with Other',
						'type' => 'radio',
						'choices' => [
							'Option 0',
							'Option 1',
							'Option 2',
							'Option 3',
							'Option 4',
						],
						'allow_null' => 1,
						'other_choice' => 1,
					],
					'true_false' => [
						'label' => 'True/False',
						'type' => 'true_false',
						'message' => 'Checkbox message',
					],
					'true_false_nolabel' => [
						'label' => '',
						'type' => 'true_false',
						'message' => 'Do you accept the terms? (true/false with blank label)',
					],
					'true_false_ui' => [
						'label' => 'True/False with UI',
						'type' => 'true_false',
						'ui' => 1,
						'ui_on_text' => 'Yep',
						'ui_off_text' => 'Nope',
						'message' => 'Send me emails',
					],
					'oembed' => [
						'label' => 'oEmbed',
						'type' => 'oembed',
					],
					'map' => [
						'label' => 'Map',
						'type' => 'google_map',
					],
					'date' => [
						'label' => 'Date',
						'type' => 'date_picker',
					],
					'time' => [
						'label' => 'Time',
						'type' => 'time_picker',
					],
					'datetime' => [
						'label' => 'Date & Time',
						'type' => 'date_time_picker',
					],
					'color' => [
						'label' => 'Colour',
						'type' => 'color_picker',
					],
					'message' => [
						'label' => 'Message',
						'type' => 'message',
						'message' => 'Some <strong>HTML</strong> that can be <u>inserted</u> into the form.',
					],
					'repeater_table' => [
						'label' => 'Repeater - Table Layout',
						'type' => 'repeater',
						'button_label' => 'Add File',
						'layout' => 'table',
						'sub_fields' => [
							'title' => [
								'label' => 'Title',
								'type' => 'text',
							],
							'file' => [
								'label' => 'File',
								'type' => 'file',
							],
						],
					],
					'repeater_block' => [
						'label' => 'Repeater - Block Layout',
						'type' => 'repeater',
						'button_label' => 'Add File',
						'layout' => 'block',
						'sub_fields' => [
							'title' => [
								'label' => 'Title',
								'type' => 'text',
							],
							'file' => [
								'label' => 'File',
								'type' => 'file',
							],
						],
					],
					'repeater_row' => [
						'label' => 'Repeater - Row Layout',
						'type' => 'repeater',
						'button_label' => 'Add File',
						'layout' => 'row',
						'sub_fields' => [
							'title' => [
								'label' => 'Title',
								'type' => 'text',
							],
							'file' => [
								'label' => 'File',
								'type' => 'file',
							],
						],
					],
					'flexible_content' => [
						'label' => 'Flexible Content',
						'type' => 'flexible_content',
						'button_label' => 'Add Attachment',
						'layouts' => [
							'uploaded_file_table' => [
								'label' => 'Uploaded File - Table Layout',
								'display' => 'table',
								'sub_fields' => [
									'title' => [
										'label' => 'Title',
										'type' => 'text',
									],
									'file' => [
										'label' => 'File',
										'type' => 'file',
									],
								],
							],
							'uploaded_file_block' => [
								'label' => 'Uploaded File - Block Layout',
								'display' => 'block',
								'sub_fields' => [
									'title' => [
										'label' => 'Title',
										'type' => 'text',
									],
									'file' => [
										'label' => 'File',
										'type' => 'file',
									],
								],
							],
							'uploaded_file_row' => [
								'label' => 'Uploaded File - Row Layout',
								'display' => 'row',
								'sub_fields' => [
									'title' => [
										'label' => 'Title',
										'type' => 'text',
									],
									'file' => [
										'label' => 'File',
										'type' => 'file',
									],
								],
							],
						],
					],
					'tab_1' => [
						'label' => 'Tab 1',
						'type' => 'tab',
					],
					'tab_1_field' => [
						'label' => 'Text Field',
						'type' => 'text',
					],
					'tab_2' => [
						'label' => 'Tab 2',
						'type' => 'tab',
					],
					'tab_2_field' => [
						'label' => 'Another Text Field',
						'type' => 'text',
					],
					'tab_3' => [
						'label' => 'Tab 3',
						'type' => 'tab',
					],
					'tab_3_field' => [
						'label' => 'Yet Another Text Field',
						'type' => 'text',
					],
				],
				'position' => 'normal',
				'style' => 'default',
				'label_placement' => 'left',
				'instruction_placement' => 'field',
				'active' => 1,
			],
		];
	}

	public function submit( $form, $fields, $args ) {

		$this->restrict_form();

		// Extract special fields into their own variables for custom processing.
		// Also remove them from the original field list to prevent them from being added as meta fields.
		foreach ( $fields as $index => $field ) {
			switch ( $field['name'] ) {
				case 'title':   $title   = $field['_input']; unset($fields[$index]); break;
				case 'content': $content = $field['_input']; unset($fields[$index]); break;
				case 'image':   $img_id  = $field['_input']; unset($fields[$index]); break;
			}
		}

		// Clean up content
		$content = wp_kses_post( $content );

		// Draft Feature
		$post_status = ( $this->using_feature( 'Draft' ) && $this->draft_submitted() ) ? 'draft' : 'publish';

		$post_data = array(
			'post_type'    => $this->post_type,
			'post_status'  => $post_status,
			'post_title'   => $title,
			'post_content' => $content,
		);

		$new_post_id = wp_insert_post( $post_data );

		// Something didn't work
		if ( !$new_post_id ) {
			return;
		}

		foreach ( $fields as $field ) {
			// Ignore non-input fields
			if ( array_key_exists( '_input', $field ) ) {
				af_save_field( $field['key'], $new_post_id );
			}
		}

		// Featured Image
		if ( ! empty( $img_id ) && is_numeric( $img_id ) ) {
			set_post_thumbnail( $post_id, $img_id );
		}

		// Extra Features
		//$this->Expiry_schedule_on_save_post( $new_post_id );

		// Show the user their new post
		wp_redirect( get_permalink( $new_post_id ) );

		die();
	}
}

new Example();
