<?php

namespace Roots\Sage\OEmbed;

function override_html( $html, $url, $attr, $post_ID ) {
	$oembed = _wp_oembed_get_object();
	$provider = $oembed->get_provider( $url );

	$extra_params = '';
	$wrap_aspect = null;

	switch ( $provider ) {

		// To override a provider, see the list in the constructor of /wp-includes/class-oembed.php
		// You want the URL, not the regular expression, and change `{format}` to `json` if present.

		case 'https://www.youtube.com/oembed':
			$extra_params = http_build_query( [
				// https://developers.google.com/youtube/player_parameters
				// 'enablejsapi' => '1', // Enable the JS API. Must be used in conjunction with the 'origin' param below
				// 'origin' => home_url(), // Only allow JS access from this origin
				// 'iv_load_policy' => '3', // Hide annotations
				'modestbranding' => '1', // Hide most YouTube branding
				'rel' => '0', // Disable related videos after video ends
				'controls' => '2', // Lazy-load player after user interacts. Speeds up page load.
			] );
			$wrap_aspect = '16by9';
			break;
		
		case 'https://vimeo.com/api/oembed.json':
			$extra_params = http_build_query( [
				// 'api' => 'true', // Enables the JS API
				'color' => '01aeb8', // Custom theme colour
			] );
			$wrap_aspect = '16by9';
			break;

	}

	if ( ! empty( $extra_params ) ) {
		$html = preg_replace( '/src="([^"\?]+)\??([^"]*)"/', 'src="$1?$2&' . $extra_params . '"', $html );
	}

	// Don't make the videos huge in the text editor
	if ( $wrap_aspect && ! is_admin() ) {
		$html = sprintf( '<div class="embed-responsive embed-responsive-%s">%s</div>', $wrap_aspect, $html );
	}

	return $html;
}
add_filter( 'embed_oembed_html', __NAMESPACE__.'\\override_html', 10, 4 );
