<?php

namespace Roots\Sage\Setup;

use Roots\Sage\Assets;

/**
 * Theme setup
 */
function setup() {
  // Enable features from Soil when plugin is activated
  // https://roots.io/plugins/soil/
  add_theme_support('soil-clean-up');
  add_theme_support('soil-nav-walker');
  add_theme_support('soil-nice-search');
  add_theme_support('soil-jquery-cdn');
  add_theme_support('soil-relative-urls');

  // Make theme available for translation
  // Community translations can be found at https://github.com/roots/sage-translations
  load_theme_textdomain('sage', get_template_directory() . '/lang');

  // Enable plugins to manage the document title
  // http://codex.wordpress.org/Function_Reference/add_theme_support#Title_Tag
  add_theme_support('title-tag');

  // Register wp_nav_menu() menus
  // http://codex.wordpress.org/Function_Reference/register_nav_menus
  register_nav_menus([
    'primary_navigation' => __('Primary Navigation', 'sage'),
    'social_navigation' => __('Social Navigation', 'sage'),
    'footer_navigation' => __('Footer Navigation', 'sage')
    
  ]);

  // Enable post thumbnails
  // http://codex.wordpress.org/Post_Thumbnails
  // http://codex.wordpress.org/Function_Reference/set_post_thumbnail_size
  // http://codex.wordpress.org/Function_Reference/add_image_size
  add_theme_support('post-thumbnails');

  // Enable post formats
  // http://codex.wordpress.org/Post_Formats
  add_theme_support('post-formats', ['aside', 'gallery', 'link', 'image', 'quote', 'video', 'audio']);

  // Enable HTML5 markup support
  // http://codex.wordpress.org/Function_Reference/add_theme_support#HTML5
  add_theme_support('html5', ['caption', 'comment-form', 'comment-list', 'gallery', 'search-form']);

  // Use main stylesheet for visual editor
  // To add custom styles edit /assets/styles/layouts/_tinymce.scss
  if (function_exists('get_field')) {
     $css_file_name = get_field('theme_option_color', 'options');
  }
  add_editor_style(Assets\asset_path("styles/$css_file_name.css"));
}
add_action('after_setup_theme', __NAMESPACE__ . '\\setup');

/**
 * Register sidebars
 */
function widgets_init() {
  register_sidebar([
    'name'          => __('Primary', 'sage'),
    'id'            => 'sidebar-primary',
    'before_widget' => '<section class="widget %1$s %2$s">',
    'after_widget'  => '</section>',
    'before_title'  => '<h3>',
    'after_title'   => '</h3>'
  ]);

  register_sidebar([
    'name'          => __('Footer', 'sage'),
    'id'            => 'sidebar-footer',
    'before_widget' => '<section class="widget %1$s %2$s">',
    'after_widget'  => '</section>',
    'before_title'  => '<h3>',
    'after_title'   => '</h3>'
  ]);
}
add_action('widgets_init', __NAMESPACE__ . '\\widgets_init');

/**
 * Determine which pages should NOT display the sidebar
 */
function display_sidebar() {
  static $display;

  isset($display) || $display = !in_array(true, [
    // The sidebar will NOT be displayed if ANY of the following return true.
    // @link https://codex.wordpress.org/Conditional_Tags
    is_404(),
    is_front_page(),
    is_page_template('template-custom.php'),
  ]);

  return apply_filters('sage/display_sidebar', $display);
}

/**
 * Theme assets
 */
function assets() {
  $css_file_name = get_field('theme_option_color', 'options');
  wp_enqueue_style('sage/css', home_url(wp_make_link_relative(Assets\asset_path("styles/$css_file_name.css"))), false, null);
  wp_enqueue_style('Poppins/font', 'https://fonts.googleapis.com/css?family=Poppins:300,400,500,600,700', false, null);

  //enqueue jQuery Cookie
  wp_enqueue_script( 'jquery-cookie', "https://cdnjs.cloudflare.com/ajax/libs/jquery-cookie/1.4.1/jquery.cookie.min.js" );

  if (is_single() && comments_open() && get_option('thread_comments')) {
    wp_enqueue_script('comment-reply');
  }

  wp_enqueue_script('sage/js', home_url(wp_make_link_relative(Assets\asset_path('scripts/main.js'))), ['jquery'], null, true);

  $typekitID = '';
  $typekitID = get_field('typekit_key', 'options');
  //var_dump($typekitID);
  wp_localize_script('sage/js', 'SAGE', [
    'typekitId'=> $typekitID
  ]);
}
add_action('wp_enqueue_scripts', __NAMESPACE__ . '\\assets', 100);

/**
 * Allow SVG media for admin users
 */
add_filter('upload_mimes', __NAMESPACE__ . '\\upload_mimes_svg', 10, 2);
function upload_mimes_svg($existing_mimes, $user){
  $unfiltered_allowed = false;
  if ( function_exists( 'current_user_can' ) ) {
    $unfiltered_allowed = $user ? user_can( $user, 'unfiltered_html' ) : current_user_can( 'unfiltered_html' );
  }
  if ( !empty( $unfiltered_allowed ) ) {
    // This user is already allowed to upload HTML files, so SVG should be okay
    $existing_mimes['svg'] = 'image/svg+xml';
  }
  return $existing_mimes;
}

function deduplicate_scripts_styles( $tag, $handle, $src ) {
  static $output_handles = [];

  if ( in_array( $handle, $output_handles ) ) {
    $tag = '';
  } else {
    $output_handles[] = $handle;
  }

  return $tag;
}
add_filter( 'script_loader_tag', __NAMESPACE__.'\\deduplicate_scripts_styles', 10, 3 );


// Add to existing function.php file
// Disable support for comments and trackbacks in post types
function df_disable_comments_post_types_support() {
  $post_types = get_post_types();
  foreach ($post_types as $post_type) {
    if(post_type_supports($post_type, 'comments')) {
      remove_post_type_support($post_type, 'comments');
      remove_post_type_support($post_type, 'trackbacks');
    }
  }
}
add_action('admin_init', __NAMESPACE__.'\\df_disable_comments_post_types_support');
// Close comments on the front-end
function df_disable_comments_status() {
  return false;
}
add_filter('comments_open', __NAMESPACE__.'\\df_disable_comments_status', 20, 2);
add_filter('pings_open', __NAMESPACE__.'\\df_disable_comments_status', 20, 2);
// Hide existing comments
function df_disable_comments_hide_existing_comments($comments) {
  $comments = array();
  return $comments;
}
add_filter('comments_array', __NAMESPACE__.'\\df_disable_comments_hide_existing_comments', 10, 2);
// Remove comments page in menu
function df_disable_comments_admin_menu() {
  remove_menu_page('edit-comments.php');
}
add_action('admin_menu', __NAMESPACE__.'\\df_disable_comments_admin_menu');
// Redirect any user trying to access comments page
function df_disable_comments_admin_menu_redirect() {
  global $pagenow;
  if ($pagenow === 'edit-comments.php') {
    wp_redirect(admin_url()); exit;
  }
}
add_action('admin_init', __NAMESPACE__.'\\df_disable_comments_admin_menu_redirect');
// Remove comments metabox from dashboard
function df_disable_comments_dashboard() {
  remove_meta_box('dashboard_recent_comments', 'dashboard', 'normal');
}
add_action('admin_init', __NAMESPACE__.'\\df_disable_comments_dashboard');
// Remove comments links from admin bar
function df_disable_comments_admin_bar() {
  if (is_admin_bar_showing()) {
    remove_action('admin_bar_menu', 'wp_admin_bar_comments_menu', 60);
  }
}
add_action('init', __NAMESPACE__.'\\df_disable_comments_admin_bar');

function edit_the_permalink($post_link, $post, $leavename, $sample){
  $venue_link = '';
  //var_dump(get_field('venue_web_link'));
  //var_dump($post);
  if($post->post_type === 'venue'){
    if (function_exists('get_field')) {
      $venue_link = get_field('venue_web_link');
      if(!empty($venue_link)){
        $post_link = $venue_link;
      }
    }
  }
  return $post_link; 
}
add_filter('post_type_link', __NAMESPACE__.'\\edit_the_permalink', 10, 4);
