<?php

namespace Roots\Sage\Venue;

use Roots\Sage\ACF;

/**
 * Register Venue Custom Post Type
 */
 
function custom_post_type_venue() {
    $args = array(
        'hierarchical'      => true,
        'labels'            => array(
          'name'              => _x( 'Venue Types', 'taxonomy general name', 'textdomain' ),
          'singular_name'     => _x( 'Venue Type', 'taxonomy singular name', 'textdomain' ),
          'search_items'      => __( 'Search Venue Types', 'textdomain' ),
          'all_items'         => __( 'All Venue Types', 'textdomain' ),
          'parent_item'       => __( 'Parent Venue Type', 'textdomain' ),
          'parent_item_colon' => __( 'Parent Venue Type:', 'textdomain' ),
          'edit_item'         => __( 'Edit Venue Type', 'textdomain' ),
          'update_item'       => __( 'Update Venue Type', 'textdomain' ),
          'add_new_item'      => __( 'Add New Venue Type', 'textdomain' ),
          'new_item_name'     => __( 'New Venue Type Name', 'textdomain' ),
          'menu_name'         => __( 'Venue Types', 'textdomain' ),
        ),
        'show_ui'           => true,
        'show_admin_column' => true,
        'query_var'         => true,
        'rewrite'           => array( 'slug' => 'venue_types' ),
      );
    
    register_taxonomy( 'venue_type', array( 'venue' ), $args );

    $labels = array(
        'name'                  => _x( 'Venues', 'Post Type General Name', 'text_domain' ),
        'singular_name'         => _x( 'Venue', 'Post Type Singular Name', 'text_domain' ),
        'menu_name'             => __( 'Venues', 'text_domain' ),
        'name_admin_bar'        => __( 'Venue', 'text_domain' ),
        'archives'              => __( 'Item Archives', 'text_domain' ),
        'parent_item_colon'     => __( 'Parent Item:', 'text_domain' ),
        'all_items'             => __( 'All Venues', 'text_domain' ),
        'add_new_item'          => __( 'Add New Venue', 'text_domain' ),
        'add_new'               => __( 'Add New Venue', 'text_domain' ),
        'new_item'              => __( 'New Venue', 'text_domain' ),
        'edit_item'             => __( 'Edit Venue', 'text_domain' ),
        'update_item'           => __( 'Update Venue', 'text_domain' ),
        'view_item'             => __( 'View Venue', 'text_domain' ),
        'search_items'          => __( 'Search Venue', 'text_domain' ),
        'not_found'             => __( 'Not found', 'text_domain' ),
        'not_found_in_trash'    => __( 'Not found in Trash', 'text_domain' ),
        'featured_image'        => __( 'Featured Image', 'text_domain' ),
        'set_featured_image'    => __( 'Set featured image', 'text_domain' ),
        'remove_featured_image' => __( 'Remove featured image', 'text_domain' ),
        'use_featured_image'    => __( 'Use as featured image', 'text_domain' ),
        'insert_into_item'      => __( 'Insert into item', 'text_domain' ),
        'uploaded_to_this_item' => __( 'Uploaded to this item', 'text_domain' ),
        'items_list'            => __( 'Items list', 'text_domain' ),
        'items_list_navigation' => __( 'Items list navigation', 'text_domain' ),
        'filter_items_list'     => __( 'Filter items list', 'text_domain' ),
    );
    $args = array(
        'label'                 => __( 'Venue', 'text_domain' ),
        'description'           => __( 'Venue', 'text_domain' ),
        'labels'                => $labels,
        'supports'              => array( 'title', 'editor', 'thumbnail' ),
        'taxonomies'            => array('venue_type'),
        'hierarchical'          => false,
        'public'                => true,
        'show_ui'               => true,
        'show_in_menu'          => true,
        'menu_position'         => 5,
        'show_in_admin_bar'     => true,
        'show_in_nav_menus'     => true,
        'can_export'            => true,
        'has_archive'           => true,
        'rewrite' => array('slug' => 'venues'),
        'exclude_from_search'   => false,
        'publicly_queryable'    => true,
        'capability_type'       => 'page',
    );
    register_post_type( 'venue', $args );

}
add_action( 'init', __NAMESPACE__ . '\\custom_post_type_venue', 0 );


function disable_pagination($query) {
    
    if( is_post_type_archive( 'venue' ) ) {
        $query->set( 'posts_per_page', -1 );
    }
    
}
add_action( 'pre_get_posts', __NAMESPACE__ . '\\disable_pagination', 10, 1 );


// Custom Fields Definition
function register_custom_fields() {
    
        ACF\register_groups([
            'cpt_archive_venue' => [
                'title' => 'Venue Archive Page Content',
                'menu_order' => 0,
                'position' => 'normal',
                'style' => 'seamless',
                'label_placement' => 'top',
                'instruction_placement' => 'label',
                'hide_on_screen' => '',
                'active' => 1,
                'description' => '',
                'location' => [
                    [
                        [
                            'param' => 'options_page',
                            'operator' => '==',
                            'value' => 'venue-archive',
                        ],
                    ],
                ],
                'fields' => [
                    'header_one' => [
                    'label' => 'Header One',
                    'type' => 'textarea'
                    ],
                    'header_two' => [
                    'label' => 'Header Two',
                    'type' => 'textarea'
                    ]
                ],
            ],
        ]);
    
    }
    add_action( 'acf/init', __NAMESPACE__.'\\register_custom_fields' );
    
    // Custom Fields Page
    function register_options_page() {
        if ( function_exists('acf_add_options_sub_page') ) {
    
            acf_add_options_sub_page(array(
                'page_title'  => 'Venue Archive Settings',
                'menu_title'  => 'Archive Settings',
                'parent_slug' => 'edit.php?post_type=venue',
                'menu_slug' => 'venue-archive',
            ));
    
        }
    }
    add_action( 'init', __NAMESPACE__.'\\register_options_page' );