<?php
namespace GM\VirtualPages;

/**
 * @author  Giuseppe Mazzapica <giuseppe.mazzapica@gmail.com>
 * @license http://opensource.org/licenses/MIT MIT
 */

class Controller implements ControllerInterface {

  private $pages;
  private $loader;
  private $matched;

  function __construct( TemplateLoaderInterface $loader ) {
    $this->pages = new \SplObjectStorage;
    $this->loader = $loader;
  }

  function init() {
    do_action( 'gm_virtual_pages', $this );
  }

  function register_query_vars( $vars ) {
    $vars[] = 'virtual_page_url';
    return $vars;
  }

  function addPage( PageInterface $page ) {
    $this->pages->attach( $page );
    $url_regex = sprintf( '%s/?$', preg_quote( trim( $page->getUrl(), '/' ) ) );
    add_rewrite_rule( $url_regex, 'index.php?virtual_page_url=' . urlencode( $page->getUrl() ), 'top' );
    return $page;
  }

  function dispatch( \WP $wp ) {
    if ( $this->checkRequest( $wp ) && $this->matched instanceof Page ) {
      $this->loader->init( $this->matched );
      $wp->virtual_page = $this->matched;
      $this->setupQuery( $wp );
      do_action( 'wp', $wp );
      $this->loader->load();
      $this->handleExit();
    }
  }

  private function checkRequest( $wp ) {
    $this->pages->rewind();
    if ( empty( $wp->query_vars['virtual_page_url'] ) ) return;
    $page_url = $wp->query_vars['virtual_page_url'];
    while( $this->pages->valid() ) {
      if ( $this->pages->current()->getUrl() === $page_url ) {
        $this->matched = $this->pages->current();
        return TRUE;
      }
      $this->pages->next();
    }
  }

  private function getPathInfo() {
    return wp_make_link_relative( add_query_arg( array() ) );
  }

  private function setupQuery( $wp ) {
    global $wp_query;
    $wp_query->init();
    $wp_query->query_vars    = $wp->query_vars;
    $wp_query->query         = $wp->query_vars;
    $wp_query->is_page       = TRUE;
    $wp_query->is_singular   = TRUE;
    $wp_query->is_home       = FALSE;
    $wp_query->found_posts   = 1;
    $wp_query->post_count    = 1;
    $wp_query->max_num_pages = 1;
    $posts = (array) apply_filters(
      'the_posts', array( $this->matched->asWpPost() ), $wp_query
    );
    $post = $posts[0];
    $wp_query->posts          = $posts;
    $wp_query->post           = $post;
    $wp_query->queried_object = $post;
    $GLOBALS['post']          = $post;
    $wp_query->virtual_page   = $post instanceof \WP_Post && isset( $post->is_virtual )
      ? $this->matched
      : NULL;
  }

  public function handleExit() {
    exit();
  }
}
