<?php

namespace Roots\Sage\WooCommerce;

function custom_merge_field_find( $find, $email ) {

	$find['status'] = '{status}';

	return $find;
}
add_filter( 'woocommerce_email_format_string_find', __NAMESPACE__.'\\custom_merge_field_find', 10, 2 );

function custom_merge_field_replace( $replace, $email ) {

	$replace['status'] = wc_get_order_status_name( $email->object->get_status() );

	return $replace;
}
add_filter( 'woocommerce_email_format_string_replace', __NAMESPACE__.'\\custom_merge_field_replace', 10, 2 );

function tickets_allow_public_scanning( $can_scan ) {

	if ( ( $_REQUEST['secret'] ?? '' ) == 'scanpass2018' ) {
		$can_scan = true;
	}

	return $can_scan;
}
add_filter( 'woocommerce_box_office_scan_permission', __NAMESPACE__.'\\tickets_allow_public_scanning', 10, 1 );

// Override the ticket scanning ajax url to append the secret
add_action( 'wp_enqueue_scripts', function() {
  $secret = $_REQUEST['secret'] ?? false;

  if ( !$secret ) return;

  $oldURL = admin_url( 'admin-ajax.php' );
  $newURL = add_query_arg( 'secret', $secret, $oldURL );
  $newURL = json_encode( $newURL );

  wp_add_inline_script( 'woocommerce_order_barcodes-frontend', <<<JS
( function() {
  try {
    wc_order_barcodes.ajaxurl = $newURL;
  } catch ( e ) {
    // Nothing
  }
} )();
JS
  , 'after' );
} );


// Customize

// Add cart to nav

/**
* Add a custom link to the end of a specific menu that uses the wp_nav_menu() function
*/
// add_filter('wp_nav_menu_items', __NAMESPACE__.'\\add_mini_cart', 10, 2);
// function add_mini_cart($items, $args){
//     if( $args->theme_location == 'primary_navigation' ){
//         $items .= '<li>here' . get_template_part("../templates/mini-cart") . '</li>';
//     }
//     return $items;
// }

//Remove Sales Flash
add_filter('woocommerce_sale_flash', __NAMESPACE__.'\\woo_custom_hide_sales_flash');
function woo_custom_hide_sales_flash()
{
    return false;
}

//Remove Product Image

add_action('template_redirect', __NAMESPACE__.'\\remove_gallery_and_product_images');
function remove_gallery_and_product_images() {
if ( is_product() ) {
    remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_images', 20 );
    }
}

//Remove Product Description
//remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_title', 5);
//remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10);
//remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20);
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );

// remove product description from single product pages
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 10 );
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );

//remove_action( 'woocommerce_before_single_product', 'wc_print_notices', 10 );

// custom datepicker for woocheckout
add_filter( 'woocommerce_form_field_datepicker', __NAMESPACE__.'\\wooccm_checkout_field_datepicker_handler', 11, 4 );

function wooccm_checkout_field_datepicker_handler( $field = '', $key, $args, $value ) {

	global $current_user;

	$user_roles = $current_user->roles;
	$user_role = array_shift($user_roles);

	if( !empty($args['user_role']) && (!empty($args['role_options']) || !empty($args['role_options2'])) ) {
		$rolekeys = explode('||',$args['role_options']);
		$rolekeys2 = explode('||',$args['role_options2']);
		if( !empty($args['role_options']) && !in_array($user_role, $rolekeys) ) {
			return;
		}
		if( !empty($args['role_options2']) && in_array($user_role, $rolekeys2) ) {
			return;
		}
	}


	if( ( !empty( $args['clear'] ) ) )
		$after = '<div class="clear"></div>';
	else
		$after = '';

	if( $args['wooccm_required'] ) {
		$args['class'][] = 'validate-required';
		$required = ' <abbr class="required" title="' . esc_attr( 'required', 'woocommerce-checkout-manager'  ) . '">*</abbr>';
	} else {
		$required = '';
	}

	$field = '<p class="form-row ' . implode( ' ', $args['class'] ) .'MyDate'.$args['cow'].' wccs-form-row-wide" id="' . $key . '_field">
					<label for="' . $key . '" class="' . implode( ' ', $args['label_class'] ) .'">' . $args['label'] . $required . '</label>
					<input type="date" class="input-text" name="' . $key . '" id="' . $key . '" placeholder="' . $args['placeholder'] . '" value="'. $value.'" />
				</p>' . $after;

	return $field;

}

/* 
* Change back to shop button in empty cart
**/

function wc_empty_cart_redirect_url() {
	$url = esc_url(home_url('/shop'));
    return $url;
}

add_filter( 'woocommerce_return_to_shop_redirect', __NAMESPACE__ . '\\wc_empty_cart_redirect_url' );

/*
* Add custom email subject line
**/

add_filter('woocommerce_email_subject_new_order', __NAMESPACE__ . '\\change_admin_email_subject', 1, 2);

function change_admin_email_subject( $subject, $order ) {
	global $woocommerce;

	$blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);
	$subject = sprintf( '[%s] New Customer Order (# %s) from Name %s %s', $blogname, $order->id, $order->billing_first_name, $order->billing_last_name );
	//$subject = sprintf( 'Your Gold Coast Pet Expo ticket purchase is complete', $blogname, $order->id, $order->billing_first_name, $order->billing_last_name );

	return $subject;
}

add_filter( 'woocommerce_box_office_order_tickets_title', __NAMESPACE__ . '\\change_ticket_title_text' ); 
add_filter( 'woocommerce_box_office_order_tickets_title', __NAMESPACE__ . '\\change_ticket_title_text' ); 


function change_ticket_title_text($title_text) {
	$title_text = 'Print tickets';
	return $title_text;
}

add_filter( 'woocommerce_box_office_order_tickets_description', __NAMESPACE__ . '\\change_ticket_description_text' ); 
add_filter( 'woocommerce_box_office_user_tickets_description', __NAMESPACE__ . '\\change_ticket_description_text' ); 


function change_ticket_description_text($description) {
	$description = 'Print tickets using links below';
	return $description;
}

// Prefix ticket numbers
add_filter( 'woocommerce_order_number', __NAMESPACE__ . '\\change_woocommerce_order_number', 1, 2);

function change_woocommerce_order_number( $order_id, $order ) {
		$prefix = get_bloginfo('name') . '-';
    $suffix = '-' . date('Y'); 
    // You can use either one of $order->id (or) $order_id
    // Both will work
    return $prefix . $order_id . $suffix;
}